@@ -16,7 +16,7 @@ tqdm.pandas()
 
 class DateTimeFeats(object):
     """
-    pandas 时间/日期特征工程
+    pandas_utils 时间/日期特征工程
     常见格式：
         1. 时间戳
         2. 时间字符串
