@@ -11,10 +11,11 @@
 import featuretools
 import featuretools as ft
 import featuretools.variable_types as vt
-from featuretools.selection import remove_low_information_features
+from featuretools.selection import remove_low_information_features, remove_single_value_features
 
 from tqdm.auto import tqdm
 from tql.pipe import reduce_mem_usage, cprint
+from tql.ml.automl.primitives import *
 
 
 # todo： 增加时间特征
@@ -46,10 +47,32 @@ class AutoFeat(object):
             self.es.normalize_entity(self.entity_id, col, col)
 
     def run_dfs(self, max_depth=1, features_only=True, chunk_size=None, n_jobs=1, ignore_variables=None,
-                reduce_mem=True, **kwargs):
-        """Deep Feature Synthesis"""
+                reduce_mem=False, trans_primitives=None, agg_primitives=None, **kwargs):
+        """Deep Feature Synthesisf
+        agg_primitives (list[str or AggregationPrimitive], optional): List of Aggregation
+            Feature types to apply.
+
+                Default: ["sum", "std", "max", "skew", "min", "mean", "count", "percent_true", "num_unique", "mode"]
+                DateTime: ['time_since_last', 'time_since_first', 'trend']
+
+        trans_primitives (list[str or TransformPrimitive], optional):
+            List of Transform Feature functions to apply.
+
+                Default: ["day", "year", "month", "weekday", "haversine", "num_words", "num_characters"]
+
+        groupby_trans_primitives (list[str or :class:`.primitives.TransformPrimitive`], optional):
+            list of Transform primitives to make GroupByTransformFeatures with
+
+        """
         if ignore_variables is None:
-            ignore_variables = [self.target_entity_id, self.index]  #
+            ignore_variables = [self.target_entity_id, self.index]
+
+        if trans_primitives is None:
+            trans_primitives = [
+                "year", "month", "day", "hour", "minute", "week", "weekday", "is_weekend",
+                'time_since_previous',  # diff
+                Quarter(), WeekOfYear(),
+            ]
 
         _ = ft.dfs(
             entityset=self.es,
@@ -60,6 +83,8 @@ class AutoFeat(object):
             chunk_size=chunk_size,
             n_jobs=n_jobs,
             verbose=1,
+            trans_primitives=trans_primitives,
+            agg_primitives=agg_primitives,
             **kwargs
         )
 
@@ -68,6 +93,7 @@ class AutoFeat(object):
         else:
             df_ = _[0].add_prefix(f'{self.entity_id}_').reset_index()
             df_ = remove_low_information_features(df_)
+            df_ = remove_single_value_features(df_, count_nan_as_value=True)
 
             if reduce_mem:
                 df_ = reduce_mem_usage(df_)
