@@ -7,6 +7,7 @@ __mtime__ = '18-12-14'
 """
 from .utils.xx import xx
 from .utils import cprint
+from .utils.time import timer
 from .utils.pandas_utils import reduce_mem_usage
 
 #########################################################################
@@ -27,6 +28,7 @@ import jieba.analyse as ja
 from pathlib import Path
 from tqdm.auto import tqdm
 from functools import reduce
+from functools import lru_cache
 from collections import Counter, OrderedDict
 from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
 
@@ -46,14 +48,27 @@ try:
     local_info = {'hostname': hostname, 'localhost': localhost, 'ip': localhost}
 
     is_dev = True if hostname.__contains__("yuanjie") else False
+
 except Exception as e:
     print(e)
 
 getsize = lambda obj: sys.getsizeof(obj) / 1024 ** 2  # M
 
-getsize_df = lambda df: df.memory_usage().sum() / 1024 ** 2  #
-###################################################################
+getsize_df = lambda df: df.memory_usage().sum() / 1024 ** 2
 
+try:
+    import tensorflow as tf
+
+    gpu_list = tf.config.list_physical_devices('GPU')
+    if gpu_list:
+        use_gpu = int(os.environ.get('USE_GPU', '0'))
+    else:
+        use_gpu = 0
+
+except Exception as e:
+    use_gpu = 0
+
+###################################################################
 
 import seaborn as sns
 
@@ -65,7 +80,6 @@ sns.set_context('paper')
 # sns.axes_style()
 # plt.style.use('ggplot')
 
-
 #########################################################################
 
 # 序列化
@@ -147,6 +161,8 @@ xjoin = xx(lambda s, sep=' ': sep.join(s))
 xcut = xx(lambda s, cut_all=False: jieba.lcut(s, cut_all=cut_all))
 xtfidf = xx(lambda s, topK=20: ja.tfidf(s, topK=topK))
 
+xsame_key_dict_merge = xx(lambda dics: pd.DataFrame(dics))
+
 
 @xx
 def hump_str(string="a_b", pattern='_'):
